@@ -114,7 +114,8 @@ rstto_app_menu_item_activate (GtkMenuItem *object)
  * Returns: RsttoAppMenuItem that launches application @app_info with @file
  */
 GtkWidget *
-rstto_app_menu_item_new (GAppInfo *app_info, GFile *file)
+rstto_app_menu_item_new (GAppInfo *app_info,
+                         GFile *file)
 {
     RsttoAppMenuItem *menu_item;
     GtkWidget *image = NULL;
@@ -137,9 +138,9 @@ rstto_app_menu_item_new (GAppInfo *app_info, GFile *file)
     }
 
     gtk_menu_item_set_label (GTK_MENU_ITEM (menu_item), g_app_info_get_name (app_info));
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-G_GNUC_END_IGNORE_DEPRECATIONS
+    G_GNUC_END_IGNORE_DEPRECATIONS
 
     return GTK_WIDGET (menu_item);
 }
