@@ -19,8 +19,8 @@
 
 #include "util.h"
 #include "file.h"
-#include "thumbnailer.h"
 #include "main_window.h"
+#include "thumbnailer.h"
 
 #ifdef HAVE_MAGIC_H
 #include <magic.h>
@@ -67,6 +67,7 @@ struct _RsttoFilePrivate
     gchar *thumbnail_paths[RSTTO_THUMBNAIL_FLAVOR_COUNT];
     GdkPixbuf *pixbufs[RSTTO_THUMBNAIL_SIZE_COUNT];
     gint pixbuf_states[RSTTO_THUMBNAIL_FLAVOR_COUNT][RSTTO_THUMBNAIL_SIZE_COUNT];
+    gboolean is_thumbnail;
 
     ExifData *exif_data;
     RsttoImageOrientation orientation;
@@ -101,15 +102,11 @@ rstto_file_class_init (RsttoFileClass *klass)
     object_class->finalize = rstto_file_finalize;
 
     rstto_file_signals[RSTTO_FILE_SIGNAL_CHANGED] = g_signal_new ("changed",
-            G_TYPE_FROM_CLASS (object_class),
-            G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-            0,
-            NULL,
-            NULL,
-            g_cclosure_marshal_VOID__VOID,
-            G_TYPE_NONE,
-            0,
-            NULL);
+                                                                  G_TYPE_FROM_CLASS (object_class),
+                                                                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                                                                  0, NULL, NULL,
+                                                                  g_cclosure_marshal_VOID__VOID,
+                                                                  G_TYPE_NONE, 0);
 }
 
 /**
@@ -205,7 +202,7 @@ rstto_file_is_valid (RsttoFile *r_file)
     GtkFileFilterInfo filter_info;
     const gchar *content_type = NULL;
 
-    if (! r_file->priv->final_content_type)
+    if (!r_file->priv->final_content_type)
     {
 #ifdef HAVE_MAGIC_H
         magic_t magic = magic_open (MAGIC_MIME_TYPE | MAGIC_SYMLINK);
@@ -254,12 +251,9 @@ rstto_file_is_valid (RsttoFile *r_file)
 
         if (NULL == content_type)
         {
-            GFileInfo *file_info = g_file_query_info (
-                    r_file->priv->file,
-                    "standard::content-type",
-                    0,
-                    NULL,
-                    NULL);
+            GFileInfo *file_info = g_file_query_info (r_file->priv->file,
+                                                      "standard::content-type",
+                                                      0, NULL, NULL);
             if (NULL != file_info)
             {
                 content_type = g_file_info_get_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
@@ -296,12 +290,9 @@ rstto_file_get_display_name (RsttoFile *r_file)
 
     if (NULL == r_file->priv->display_name)
     {
-        file_info = g_file_query_info (
-                r_file->priv->file,
-                G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
-                0,
-                NULL,
-                NULL);
+        file_info = g_file_query_info (r_file->priv->file,
+                                       G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                                       0, NULL, NULL);
         if (NULL != file_info)
         {
             display_name = g_file_info_get_display_name (file_info);
@@ -392,9 +383,11 @@ rstto_file_get_modified_time (RsttoFile *r_file)
     guint64 time_ = 0;
     GFileInfo *file_info = g_file_query_info (r_file->priv->file, "time::modified", 0, NULL, NULL);
 
-    time_ = g_file_info_get_attribute_uint64 (file_info, "time::modified");
-
-    g_object_unref (file_info);
+    if (file_info != NULL)
+    {
+        time_ = g_file_info_get_attribute_uint64 (file_info, "time::modified");
+        g_object_unref (file_info);
+    }
 
     return time_;
 }
@@ -405,28 +398,28 @@ rstto_file_get_size (RsttoFile *r_file)
     goffset size = 0;
     GFileInfo *file_info = g_file_query_info (r_file->priv->file, G_FILE_ATTRIBUTE_STANDARD_SIZE, 0, NULL, NULL);
 
-    size = g_file_info_get_size (file_info);
-
-    g_object_unref (file_info);
+    if (file_info != NULL)
+    {
+        size = g_file_info_get_size (file_info);
+        g_object_unref (file_info);
+    }
 
     return size;
 }
 
 ExifEntry *
-rstto_file_get_exif (RsttoFile *r_file, ExifTag id)
+rstto_file_get_exif (RsttoFile *r_file,
+                     ExifTag id)
 {
     /* If there is no exif-data object, try to create it */
     if (NULL == r_file->priv->exif_data)
     {
-        r_file->priv->exif_data = exif_data_new_from_file (
-                rstto_file_get_path (r_file));
+        r_file->priv->exif_data = exif_data_new_from_file (rstto_file_get_path (r_file));
     }
 
     if (NULL != r_file->priv->exif_data)
     {
-        return exif_data_get_entry (
-                r_file->priv->exif_data,
-                id);
+        return exif_data_get_entry (r_file->priv->exif_data, id);
     }
 
     /* If there is no exif-data, return NULL */
@@ -444,8 +437,8 @@ rstto_file_get_orientation (RsttoFile *r_file)
         if (NULL != exif_entry)
         {
             r_file->priv->orientation = exif_get_short (
-                    exif_entry->data,
-                    exif_data_get_byte_order (exif_entry->parent->parent));
+                exif_entry->data,
+                exif_data_get_byte_order (exif_entry->parent->parent));
         }
 
         /* If the orientation-tag is not set, default to NONE */
@@ -454,15 +447,13 @@ rstto_file_get_orientation (RsttoFile *r_file)
             /* Default orientation */
             r_file->priv->orientation = RSTTO_IMAGE_ORIENT_NONE;
         }
-
     }
     return r_file->priv->orientation;
 }
 
 void
-rstto_file_set_orientation (
-        RsttoFile *r_file,
-        RsttoImageOrientation orientation)
+rstto_file_set_orientation (RsttoFile *r_file,
+                            RsttoImageOrientation orientation)
 {
     r_file->priv->orientation = orientation;
 }
@@ -515,6 +506,13 @@ rstto_file_set_thumbnail_state (RsttoFile *r_file,
     r_file->priv->thumbnail_states[flavor] = state;
 }
 
+void
+rstto_file_set_is_thumbnail (RsttoFile *r_file,
+                             gboolean is_thumbnail)
+{
+    r_file->priv->is_thumbnail = is_thumbnail;
+}
+
 static const gchar *
 rstto_file_get_thumbnail_path (RsttoFile *r_file,
                                RsttoThumbnailFlavor flavor)
@@ -522,6 +520,9 @@ rstto_file_get_thumbnail_path (RsttoFile *r_file,
     const gchar *uri, *flavor_name;
     gchar *path, *checksum, *filename;
 
+    if (r_file->priv->is_thumbnail)
+        return rstto_file_get_path (r_file);
+
     if (r_file->priv->thumbnail_paths[flavor] == NULL)
     {
         flavor_name = rstto_util_get_thumbnail_flavor_name (flavor);
@@ -532,19 +533,19 @@ rstto_file_get_thumbnail_path (RsttoFile *r_file,
         /* build and check if the thumbnail is in the new location */
         path = g_build_path ("/", g_get_user_cache_dir (), "thumbnails",
                              flavor_name, filename, NULL);
-        if (! g_file_test (path, G_FILE_TEST_EXISTS))
+        if (!g_file_test (path, G_FILE_TEST_EXISTS))
         {
             /* fallback to old version */
             g_free (path);
             path = g_build_path ("/", g_get_home_dir (), ".thumbnails",
                                  flavor_name, filename, NULL);
-            if (! g_file_test (path, G_FILE_TEST_EXISTS))
+            if (!g_file_test (path, G_FILE_TEST_EXISTS))
             {
-#if LIBXFCE4UTIL_CHECK_VERSION (4, 17, 1)
+#if LIBXFCE4UTIL_CHECK_VERSION(4, 17, 1)
                 /* fallback to shared repository */
                 g_free (path);
                 path = xfce_create_shared_thumbnail_path (uri, flavor_name);
-                if (path == NULL || ! g_file_test (path, G_FILE_TEST_EXISTS))
+                if (path == NULL || !g_file_test (path, G_FILE_TEST_EXISTS))
 #endif
                 {
                     /* thumbnail doesn't exist in either spot */
