@@ -18,8 +18,8 @@
  */
 
 #include "util.h"
-#include "monitor_chooser.h"
 #include "gnome_wallpaper_manager.h"
+#include "monitor_chooser.h"
 
 #include <libxfce4ui/libxfce4ui.h>
 
@@ -88,10 +88,9 @@ G_DEFINE_TYPE_WITH_CODE (RsttoGnomeWallpaperManager, rstto_gnome_wallpaper_manag
 
 
 static gint
-rstto_gnome_wallpaper_manager_configure_dialog_run (
-        RsttoWallpaperManager *self,
-        RsttoFile *file,
-        GtkWindow *parent)
+rstto_gnome_wallpaper_manager_configure_dialog_run (RsttoWallpaperManager *self,
+                                                    RsttoFile *file,
+                                                    GtkWindow *parent)
 {
     RsttoGnomeWallpaperManager *manager = RSTTO_GNOME_WALLPAPER_MANAGER (self);
     gint response = GTK_RESPONSE_OK;
@@ -102,11 +101,7 @@ rstto_gnome_wallpaper_manager_configure_dialog_run (
         g_object_unref (manager->priv->pixbuf);
     }
 
-    manager->priv->pixbuf = gdk_pixbuf_new_from_file_at_size (
-            rstto_file_get_path (file),
-            500,
-            500,
-            NULL);
+    manager->priv->pixbuf = gdk_pixbuf_new_from_file_at_size (rstto_file_get_path (file), 500, 500, NULL);
 
     configure_monitor_chooser_pixbuf (manager);
 
@@ -115,45 +110,38 @@ rstto_gnome_wallpaper_manager_configure_dialog_run (
     gtk_widget_hide (manager->priv->dialog);
     if ((response == GTK_RESPONSE_OK) || (response == GTK_RESPONSE_APPLY))
     {
-        manager->priv->style = gtk_combo_box_get_active (
-                GTK_COMBO_BOX (manager->priv->style_combo));
+        manager->priv->style = gtk_combo_box_get_active (GTK_COMBO_BOX (manager->priv->style_combo));
         manager->priv->monitor = rstto_monitor_chooser_get_selected (
-                RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
+            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
     }
 
     return response;
 }
 
 static gboolean
-rstto_gnome_wallpaper_manager_check_running (
-        RsttoWallpaperManager *self)
+rstto_gnome_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 {
     return TRUE;
 }
 
 static gboolean
-rstto_gnome_wallpaper_manager_set (
-        RsttoWallpaperManager *self,
-        RsttoFile *file)
+rstto_gnome_wallpaper_manager_set (RsttoWallpaperManager *self,
+                                   RsttoFile *file)
 {
     gchar *command = NULL;
 
-    command = g_strdup_printf (
-            "gsettings set org.gnome.desktop.background picture-uri %s",
-            rstto_file_get_uri (file));
+    command = g_strdup_printf ("gsettings set org.gnome.desktop.background picture-uri %s",
+                               rstto_file_get_uri (file));
 
     g_spawn_command_line_async (command, NULL);
     g_free (command);
 
-    command = g_strdup_printf (
-            "gsettings set org.gnome.desktop.background picture-options %s",
-            "scaled");
+    command = g_strdup ("gsettings set org.gnome.desktop.background picture-options scaled");
 
     g_spawn_command_line_async (command, NULL);
     g_free (command);
 
-    command = g_strdup_printf (
-            "gsettings set org.gnome.desktop.background primary-color '#000000000000'");
+    command = g_strdup ("gsettings set org.gnome.desktop.background primary-color '#000000000000'");
 
     g_spawn_command_line_async (command, NULL);
     g_free (command);
@@ -204,50 +192,20 @@ rstto_gnome_wallpaper_manager_init (RsttoGnomeWallpaperManager *manager)
 
     for (i = 0; i < n_monitors; ++i)
     {
-        gdk_monitor_get_geometry (
-                gdk_display_get_monitor (display, i),
-                &monitor_geometry);
-        rstto_monitor_chooser_add (
-                RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-                monitor_geometry.width,
-                monitor_geometry.height);
+        gdk_monitor_get_geometry (gdk_display_get_monitor (display, i), &monitor_geometry);
+        rstto_monitor_chooser_add (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                   monitor_geometry.width, monitor_geometry.height);
     }
-    gtk_box_pack_start (
-            GTK_BOX (vbox),
-            manager->priv->monitor_chooser,
-            FALSE,
-            FALSE,
-            0);
-    gtk_box_pack_start (
-            GTK_BOX (vbox),
-            image_prop_grid,
-            FALSE,
-            FALSE,
-            0);
+    gtk_box_pack_start (GTK_BOX (vbox), manager->priv->monitor_chooser, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), image_prop_grid, FALSE, FALSE, 0);
 
-    gtk_grid_attach (
-            GTK_GRID (image_prop_grid),
-            style_label,
-            0,
-            0,
-            1,
-            1);
-    gtk_grid_attach (
-            GTK_GRID (image_prop_grid),
-            manager->priv->style_combo,
-            1,
-            0,
-            1,
-            1);
+    gtk_grid_attach (GTK_GRID (image_prop_grid), style_label, 0, 0, 1, 1);
+    gtk_grid_attach (GTK_GRID (image_prop_grid), manager->priv->style_combo, 1, 0, 1, 1);
 
     gtk_widget_set_hexpand (manager->priv->style_combo, TRUE);
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Auto"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Auto"));
 
-    gtk_combo_box_set_active (
-            GTK_COMBO_BOX (manager->priv->style_combo),
-            0);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (manager->priv->style_combo), 0);
 
     // there's only one screen in GTK3
     manager->priv->screen = 0;
@@ -312,15 +270,10 @@ rstto_gnome_wallpaper_manager_new (void)
 
 
 static void
-cb_monitor_chooser_changed (
-        RsttoMonitorChooser *monitor_chooser,
-        RsttoGnomeWallpaperManager *manager)
+cb_monitor_chooser_changed (RsttoMonitorChooser *monitor_chooser,
+                            RsttoGnomeWallpaperManager *manager)
 {
-    rstto_monitor_chooser_set_image_surface (
-            monitor_chooser,
-            manager->priv->monitor,
-            NULL,
-            NULL);
+    rstto_monitor_chooser_set_image_surface (monitor_chooser, manager->priv->monitor, NULL, NULL);
 
     manager->priv->monitor = rstto_monitor_chooser_get_selected (monitor_chooser);
 
@@ -328,14 +281,13 @@ cb_monitor_chooser_changed (
 }
 
 static void
-configure_monitor_chooser_pixbuf (
-    RsttoGnomeWallpaperManager *manager)
+configure_monitor_chooser_pixbuf (RsttoGnomeWallpaperManager *manager)
 {
     cairo_surface_t *image_surface = NULL;
     cairo_t *ctx;
     GdkPixbuf *tmp_pixbuf;
     gint monitor_width, monitor_height, dest_width, dest_height,
-         surface_width, surface_height, dest_x, dest_y;
+        surface_width, surface_height, dest_x, dest_y;
     gdouble x_scale, y_scale;
 
     if (manager->priv->pixbuf)
@@ -343,19 +295,13 @@ configure_monitor_chooser_pixbuf (
         tmp_pixbuf = gdk_pixbuf_copy (manager->priv->pixbuf);
         if (NULL != tmp_pixbuf)
         {
-            rstto_monitor_chooser_get_dimensions (
-                    RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-                    manager->priv->monitor,
-                    &monitor_width,
-                    &monitor_height);
+            rstto_monitor_chooser_get_dimensions (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                                  manager->priv->monitor, &monitor_width, &monitor_height);
 
             surface_width = monitor_width * 0.2;
             surface_height = monitor_height * 0.2;
 
-            image_surface = cairo_image_surface_create (
-                    CAIRO_FORMAT_ARGB32,
-                    surface_width,
-                    surface_height);
+            image_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, surface_width, surface_height);
             ctx = cairo_create (image_surface);
 
             cairo_set_source_rgb (ctx, 0, 0, 0);
@@ -418,11 +364,7 @@ configure_monitor_chooser_pixbuf (
                     break;
             }
             cairo_scale (ctx, x_scale, y_scale);
-            gdk_cairo_set_source_pixbuf (
-                    ctx,
-                    tmp_pixbuf,
-                    dest_x / x_scale,
-                    dest_y / y_scale);
+            gdk_cairo_set_source_pixbuf (ctx, tmp_pixbuf, dest_x / x_scale, dest_y / y_scale);
             cairo_paint (ctx);
             cairo_destroy (ctx);
 
@@ -430,25 +372,19 @@ configure_monitor_chooser_pixbuf (
         }
     }
 
-    rstto_monitor_chooser_set_image_surface (
-            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-            manager->priv->monitor,
-            image_surface,
-            NULL);
+    rstto_monitor_chooser_set_image_surface (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                             manager->priv->monitor, image_surface, NULL);
 }
 
 
 static void
-cb_style_combo_changed (
-        GtkComboBox *style_combo,
-        RsttoGnomeWallpaperManager *manager)
+cb_style_combo_changed (GtkComboBox *style_combo,
+                        RsttoGnomeWallpaperManager *manager)
 {
-
     manager->priv->style = gtk_combo_box_get_active (style_combo);
 
     manager->priv->monitor = rstto_monitor_chooser_get_selected (
-            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
+        RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
 
     configure_monitor_chooser_pixbuf (manager);
 }
-
