@@ -20,10 +20,10 @@
 #ifndef __RISTRETTO_GNOME_WALLPAPER_MANAGER_H__
 #define __RISTRETTO_GNOME_WALLPAPER_MANAGER_H__
 
-#include <gtk/gtk.h>
-
 #include "wallpaper_manager.h"
 
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_GNOME_WALLPAPER_MANAGER rstto_gnome_wallpaper_manager_get_type ()
@@ -39,7 +39,8 @@ struct _RsttoGnomeWallpaperManager
 
 
 
-RsttoWallpaperManager *rstto_gnome_wallpaper_manager_new (void);
+RsttoWallpaperManager *
+rstto_gnome_wallpaper_manager_new (void);
 
 G_END_DECLS
 
