@@ -22,15 +22,9 @@
 
 #include <libxfce4ui/libxfce4ui.h>
 
-
-
-#ifndef RSTTO_MIN_CACHE_SIZE
-#define RSTTO_MIN_CACHE_SIZE 16
-#endif
-
-#ifndef RSTTO_DEFAULT_CACHE_SIZE
-#define RSTTO_DEFAULT_CACHE_SIZE 256
-#endif
+#define MAX_WIDTH_CHARS 80
+#define XALIGN 0.0
+#define YALIGN 0.5
 
 
 
@@ -60,6 +54,9 @@ static void
 cb_limit_quality_check_button_toggled (GtkToggleButton *button,
                                        gpointer user_data);
 static void
+cb_enable_smoothing_check_button_toggled (GtkToggleButton *button,
+                                          gpointer user_data);
+static void
 cb_wrap_images_check_button_toggled (GtkToggleButton *button,
                                      gpointer user_data);
 static void
@@ -91,6 +88,8 @@ struct _RsttoPreferencesDialogPrivate
 
         GtkWidget *quality_label;
         GtkWidget *quality_button;
+        GtkWidget *enable_smoothing_label;
+        GtkWidget *enable_smoothing_check_button;
     } display_tab;
 
     struct
@@ -138,7 +137,6 @@ struct _RsttoPreferencesDialogPrivate
         GtkWidget *open_entire_folder_check_button;
         GtkWidget *wrap_images_check_button;
     } behaviour_tab;
-
 };
 
 
@@ -190,18 +188,19 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
 {
     /* Variable Section */
 
-    gboolean   bool_invert_zoom_direction;
-    gboolean   bool_bgcolor_override;
-    guint      uint_slideshow_timeout;
-    gboolean   bool_hide_thumbnails_fullscreen;
-    guint      uint_hide_mouse_cursor_fullscreen_timeout;
-    gboolean   bool_wrap_images;
-    gboolean   bool_maximize_on_startup;
-    gboolean   bool_show_clock;
-    gboolean   bool_limit_quality;
-    gchar     *str_desktop_type = NULL;
+    gboolean bool_invert_zoom_direction;
+    gboolean bool_bgcolor_override;
+    guint uint_slideshow_timeout;
+    gboolean bool_hide_thumbnails_fullscreen;
+    guint uint_hide_mouse_cursor_fullscreen_timeout;
+    gboolean bool_wrap_images;
+    gboolean bool_maximize_on_startup;
+    gboolean bool_show_clock;
+    gboolean bool_limit_quality;
+    gboolean bool_enable_smoothing;
+    gchar *str_desktop_type = NULL;
 
-    GdkRGBA   *bgcolor;
+    GdkRGBA *bgcolor;
     GtkWidget *timeout_lbl, *timeout_hscale;
     GtkWidget *display_main_vbox;
     GtkWidget *display_main_lbl;
@@ -216,7 +215,7 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     GtkWidget *behaviour_desktop_lbl;
     GtkWidget *notebook = gtk_notebook_new ();
     GtkWidget *button = xfce_gtk_button_new_mixed ("window-close", _("_Close"));
-    gint       n_pages, i;
+    gint n_pages, i;
 
     /* Code Section */
 
@@ -227,20 +226,20 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     /*
      * Get all properties from the ristretto settings container
      */
-    g_object_get (
-            dialog->priv->settings,
-            "invert-zoom-direction", &bool_invert_zoom_direction,
-            "bgcolor-override", &bool_bgcolor_override,
-            "bgcolor", &bgcolor,
-            "slideshow-timeout", &uint_slideshow_timeout,
-            "hide-thumbnails-fullscreen", &bool_hide_thumbnails_fullscreen,
-            "hide-mouse-cursor-fullscreen-timeout", &uint_hide_mouse_cursor_fullscreen_timeout,
-            "maximize-on-startup", &bool_maximize_on_startup,
-            "wrap-images", &bool_wrap_images,
-            "desktop-type", &str_desktop_type,
-            "show-clock", &bool_show_clock,
-            "limit-quality", &bool_limit_quality,
-            NULL);
+    g_object_get (dialog->priv->settings,
+                  "invert-zoom-direction", &bool_invert_zoom_direction,
+                  "bgcolor-override", &bool_bgcolor_override,
+                  "bgcolor", &bgcolor,
+                  "slideshow-timeout", &uint_slideshow_timeout,
+                  "hide-thumbnails-fullscreen", &bool_hide_thumbnails_fullscreen,
+                  "hide-mouse-cursor-fullscreen-timeout", &uint_hide_mouse_cursor_fullscreen_timeout,
+                  "maximize-on-startup", &bool_maximize_on_startup,
+                  "wrap-images", &bool_wrap_images,
+                  "desktop-type", &str_desktop_type,
+                  "show-clock", &bool_show_clock,
+                  "limit-quality", &bool_limit_quality,
+                  "enable-smoothing", &bool_enable_smoothing,
+                  NULL);
 
     /*
      * Configure the display tab
@@ -289,10 +288,11 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     gtk_box_pack_start (GTK_BOX (display_main_vbox), dialog->priv->display_tab.quality_frame, FALSE, FALSE, 0);
 
     dialog->priv->display_tab.quality_label = gtk_label_new (
-            _("With this option enabled, the maximum image-quality will be limited to the screen-size."));
+        _("With this option enabled, the maximum image-quality will be limited to the screen-size."));
     gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->display_tab.quality_label), TRUE);
-    gtk_label_set_xalign (GTK_LABEL (dialog->priv->display_tab.quality_label), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (dialog->priv->display_tab.quality_label), 0.5);
+    gtk_label_set_max_width_chars (GTK_LABEL (dialog->priv->display_tab.quality_label), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->display_tab.quality_label), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->display_tab.quality_label), YALIGN);
     dialog->priv->display_tab.quality_button = gtk_check_button_new_with_label (_("Limit rendering quality"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->display_tab.quality_vbox), dialog->priv->display_tab.quality_label);
     gtk_container_add (GTK_CONTAINER (dialog->priv->display_tab.quality_vbox), dialog->priv->display_tab.quality_button);
@@ -301,6 +301,20 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     g_signal_connect (dialog->priv->display_tab.quality_button, "toggled",
                       G_CALLBACK (cb_limit_quality_check_button_toggled), dialog);
 
+    dialog->priv->display_tab.enable_smoothing_label = gtk_label_new (
+        _("Smooth the image using bilinear interpolation, thus prioritizing rendering quality over performance."));
+    gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->display_tab.enable_smoothing_label), TRUE);
+    gtk_label_set_max_width_chars (GTK_LABEL (dialog->priv->display_tab.enable_smoothing_label), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->display_tab.enable_smoothing_label), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->display_tab.enable_smoothing_label), YALIGN);
+    dialog->priv->display_tab.enable_smoothing_check_button = gtk_check_button_new_with_label (_("Enable smoothing"));
+    gtk_container_add (GTK_CONTAINER (dialog->priv->display_tab.quality_vbox), dialog->priv->display_tab.enable_smoothing_label);
+    gtk_container_add (GTK_CONTAINER (dialog->priv->display_tab.quality_vbox), dialog->priv->display_tab.enable_smoothing_check_button);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->display_tab.enable_smoothing_check_button), bool_enable_smoothing);
+
+    g_signal_connect (dialog->priv->display_tab.enable_smoothing_check_button, "toggled",
+                      G_CALLBACK (cb_enable_smoothing_check_button_toggled), dialog);
+
     /*
      * Fullscreen tab
      */
@@ -314,8 +328,9 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
 
     dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl = gtk_label_new (_("The thumbnail bar can be automatically hidden when the window is fullscreen."));
     gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), TRUE);
-    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), 0.5);
+    gtk_label_set_max_width_chars (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl), YALIGN);
     dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_check_button = gtk_check_button_new_with_label (_("Hide thumbnail bar when fullscreen"));
     gtk_box_pack_start (GTK_BOX (dialog->priv->fullscreen_tab.thumbnail_vbox), dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_lbl, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (dialog->priv->fullscreen_tab.thumbnail_vbox), dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_check_button, FALSE, FALSE, 0);
@@ -329,8 +344,9 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
 
     dialog->priv->fullscreen_tab.clock_label = gtk_label_new (_("Show an analog clock that displays the current time when the window is fullscreen"));
     gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), TRUE);
-    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), 0.5);
+    gtk_label_set_max_width_chars (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.clock_label), YALIGN);
     dialog->priv->fullscreen_tab.clock_button = gtk_check_button_new_with_label (_("Show Fullscreen Clock"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.clock_vbox), dialog->priv->fullscreen_tab.clock_label);
     gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.clock_vbox), dialog->priv->fullscreen_tab.clock_button);
@@ -340,10 +356,11 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     dialog->priv->fullscreen_tab.cursor_frame = xfce_gtk_frame_box_new_with_content (_("Mouse cursor"), dialog->priv->fullscreen_tab.cursor_vbox);
     gtk_box_pack_start (GTK_BOX (fullscreen_main_vbox), dialog->priv->fullscreen_tab.cursor_frame, FALSE, FALSE, 0);
 
-    dialog->priv->fullscreen_tab.cursor_label = gtk_label_new (_("The mouse cursor can be automatically hidden after a certain period of inactivity\nwhen the window is fullscreen."));
+    dialog->priv->fullscreen_tab.cursor_label = gtk_label_new (_("The mouse cursor can be automatically hidden after a certain period of inactivity when the window is fullscreen."));
     gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), TRUE);
-    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), 0.5);
+    gtk_label_set_max_width_chars (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), YALIGN);
     gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.cursor_vbox), dialog->priv->fullscreen_tab.cursor_label);
 
     dialog->priv->fullscreen_tab.cursor_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
@@ -373,10 +390,12 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     dialog->priv->slideshow_tab.timeout_frame = xfce_gtk_frame_box_new_with_content (_("Timeout"), dialog->priv->slideshow_tab.timeout_vbox);
     gtk_box_pack_start (GTK_BOX (slideshow_main_vbox), dialog->priv->slideshow_tab.timeout_frame, FALSE, FALSE, 0);
 
-    timeout_lbl = gtk_label_new (_("The time period an individual image is displayed during a slideshow\n(in seconds)"));
+    timeout_lbl = gtk_label_new (_("The time period an individual image is displayed during a slideshow (in seconds)"));
     timeout_hscale = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 1, 60, 1);
-    gtk_label_set_xalign (GTK_LABEL (timeout_lbl), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (timeout_lbl), 0.5);
+    gtk_label_set_line_wrap (GTK_LABEL (timeout_lbl), TRUE);
+    gtk_label_set_max_width_chars (GTK_LABEL (timeout_lbl), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (timeout_lbl), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (timeout_lbl), YALIGN);
 
     gtk_box_pack_start (GTK_BOX (dialog->priv->slideshow_tab.timeout_vbox), timeout_lbl, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (dialog->priv->slideshow_tab.timeout_vbox), timeout_hscale, FALSE, TRUE, 0);
@@ -414,8 +433,8 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     dialog->priv->behaviour_tab.maximize_window_on_startup_check_button = gtk_check_button_new_with_label (_("Maximize window on startup when opening an image"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.maximize_window_on_startup_check_button);
     gtk_toggle_button_set_active (
-            GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.maximize_window_on_startup_check_button),
-            bool_maximize_on_startup);
+        GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.maximize_window_on_startup_check_button),
+        bool_maximize_on_startup);
 
     dialog->priv->behaviour_tab.wrap_images_check_button = gtk_check_button_new_with_label (_("Wrap around images"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.wrap_images_check_button);
@@ -431,29 +450,24 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     dialog->priv->behaviour_tab.desktop_frame = xfce_gtk_frame_box_new_with_content (_("Desktop"), dialog->priv->behaviour_tab.desktop_vbox);
     gtk_box_pack_start (GTK_BOX (behaviour_main_vbox), dialog->priv->behaviour_tab.desktop_frame, FALSE, FALSE, 0);
     behaviour_desktop_lbl = gtk_label_new (NULL);
-    gtk_label_set_markup (
-            GTK_LABEL (behaviour_desktop_lbl),
-            _("Configure which system is currently managing your desktop.\n"
-              "This setting determines the method <i>Ristretto</i> will use\n"
-              "to configure the desktop wallpaper."));
-    gtk_label_set_xalign (GTK_LABEL (behaviour_desktop_lbl), 0.0);
-    gtk_label_set_yalign (GTK_LABEL (behaviour_desktop_lbl), 0.5);
+    gtk_label_set_markup (GTK_LABEL (behaviour_desktop_lbl),
+                          _("Configure which system is currently managing your desktop. "
+                            "This setting determines the method <i>Ristretto</i> will use "
+                            "to configure the desktop wallpaper."));
+    gtk_label_set_line_wrap (GTK_LABEL (behaviour_desktop_lbl), TRUE);
+    gtk_label_set_max_width_chars (GTK_LABEL (behaviour_desktop_lbl), MAX_WIDTH_CHARS);
+    gtk_label_set_xalign (GTK_LABEL (behaviour_desktop_lbl), XALIGN);
+    gtk_label_set_yalign (GTK_LABEL (behaviour_desktop_lbl), YALIGN);
     gtk_box_pack_start (GTK_BOX (dialog->priv->behaviour_tab.desktop_vbox), behaviour_desktop_lbl, FALSE, FALSE, 0);
     dialog->priv->behaviour_tab.choose_desktop_combo_box = gtk_combo_box_text_new ();
     gtk_box_pack_start (GTK_BOX (dialog->priv->behaviour_tab.desktop_vbox), dialog->priv->behaviour_tab.choose_desktop_combo_box,
                         FALSE, FALSE, 0);
-    gtk_combo_box_text_insert_text (
-            GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
-            DESKTOP_TYPE_NONE,
-            _("None"));
-    gtk_combo_box_text_insert_text (
-            GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
-            DESKTOP_TYPE_XFCE,
-            _("Xfce"));
-    gtk_combo_box_text_insert_text (
-            GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
-            DESKTOP_TYPE_GNOME,
-            _("GNOME"));
+    gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
+                                    DESKTOP_TYPE_NONE, _("None"));
+    gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
+                                    DESKTOP_TYPE_XFCE, _("Xfce"));
+    gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (dialog->priv->behaviour_tab.choose_desktop_combo_box),
+                                    DESKTOP_TYPE_GNOME, _("GNOME"));
 
     if (str_desktop_type != NULL)
     {
@@ -506,7 +520,6 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
 
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
     gtk_widget_show (button);
-
 }
 
 static void
@@ -577,9 +590,8 @@ rstto_preferences_dialog_new (GtkWindow *parent)
  *   endif
  */
 static void
-cb_bgcolor_override_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_bgcolor_override_toggled (GtkToggleButton *button,
+                             gpointer user_data)
 {
     /* Variable Section */
 
@@ -589,14 +601,9 @@ cb_bgcolor_override_toggled (
 
     /* Code Section */
 
-    gtk_widget_set_sensitive (
-            dialog->priv->display_tab.bgcolor_color_button,
-            bgcolor_override);
+    gtk_widget_set_sensitive (dialog->priv->display_tab.bgcolor_color_button, bgcolor_override);
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "bgcolor-override",
-            bgcolor_override);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "bgcolor-override", bgcolor_override);
 }
 
 /**
@@ -618,9 +625,8 @@ cb_bgcolor_override_toggled (
  *   set_property ("bg-color", color);
  */
 static void
-cb_bgcolor_color_set (
-        GtkColorButton *button,
-        gpointer user_data)
+cb_bgcolor_color_set (GtkColorButton *button,
+                      gpointer user_data)
 {
     RsttoPreferencesDialog *dialog = user_data;
     GdkRGBA *bgcolor;
@@ -659,9 +665,8 @@ cb_bgcolor_color_set (
  *   endif
  */
 static void
-cb_invert_zoom_direction_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_invert_zoom_direction_check_button_toggled (GtkToggleButton *button,
+                                               gpointer user_data)
 {
     /* Variable Section */
 
@@ -671,10 +676,7 @@ cb_invert_zoom_direction_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "invert-zoom-direction",
-            invert_zoom);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "invert-zoom-direction", invert_zoom);
 }
 
 /**
@@ -697,9 +699,8 @@ cb_invert_zoom_direction_check_button_toggled (
  *   set_property ("slideshow-timeout", value);
  */
 static void
-cb_slideshow_timeout_value_changed (
-        GtkRange *range,
-        gpointer user_data)
+cb_slideshow_timeout_value_changed (GtkRange *range,
+                                    gpointer user_data)
 {
     /* Variable Section */
 
@@ -709,11 +710,7 @@ cb_slideshow_timeout_value_changed (
 
     /* Code Section */
 
-    rstto_settings_set_uint_property (
-            dialog->priv->settings,
-            "slideshow-timeout",
-            slideshow_timeout);
-
+    rstto_settings_set_uint_property (dialog->priv->settings, "slideshow-timeout", slideshow_timeout);
 }
 
 /**
@@ -744,9 +741,8 @@ cb_slideshow_timeout_value_changed (
  *   endif
  */
 static void
-cb_hide_thumbnails_fullscreen_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_hide_thumbnails_fullscreen_check_button_toggled (GtkToggleButton *button,
+                                                    gpointer user_data)
 {
     /* Variable Section */
 
@@ -756,10 +752,7 @@ cb_hide_thumbnails_fullscreen_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "hide-thumbnails-fullscreen",
-            hide_thumbnails);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "hide-thumbnails-fullscreen", hide_thumbnails);
 }
 
 /**
@@ -791,9 +784,8 @@ cb_hide_thumbnails_fullscreen_check_button_toggled (
  *   endif
  */
 static void
-cb_wrap_images_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_wrap_images_check_button_toggled (GtkToggleButton *button,
+                                     gpointer user_data)
 {
     /* Variable Section */
 
@@ -803,10 +795,7 @@ cb_wrap_images_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "wrap-images",
-            wrap_images);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "wrap-images", wrap_images);
 }
 
 /**
@@ -837,9 +826,8 @@ cb_wrap_images_check_button_toggled (
  *   endif
  */
 static void
-cb_maximize_on_startup_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_maximize_on_startup_check_button_toggled (GtkToggleButton *button,
+                                             gpointer user_data)
 {
     /* Variable Section */
 
@@ -849,10 +837,7 @@ cb_maximize_on_startup_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "maximize-on-startup",
-            maximize_on_startup);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "maximize-on-startup", maximize_on_startup);
 }
 
 /**
@@ -883,9 +868,8 @@ cb_maximize_on_startup_check_button_toggled (
  *   endif
  */
 static void
-cb_show_clock_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_show_clock_check_button_toggled (GtkToggleButton *button,
+                                    gpointer user_data)
 {
     /* Variable Section */
 
@@ -894,10 +878,7 @@ cb_show_clock_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "show-clock",
-            show_clock);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "show-clock", show_clock);
 }
 
 /**
@@ -916,17 +897,15 @@ cb_show_clock_check_button_toggled (
  * fullscreen mode.
  */
 static void
-cb_cursor_timeout_button_value_changed (
-        GtkSpinButton *spin_button,
-        gpointer user_data)
+cb_cursor_timeout_button_value_changed (GtkSpinButton *spin_button,
+                                        gpointer user_data)
 {
     RsttoPreferencesDialog *dialog = user_data;
     gdouble value = gtk_spin_button_get_value (spin_button);
 
-    rstto_settings_set_uint_property (
-            dialog->priv->settings,
-            "hide-mouse-cursor-fullscreen-timeout",
-            value > 0 ? value : 0);
+    rstto_settings_set_uint_property (dialog->priv->settings,
+                                      "hide-mouse-cursor-fullscreen-timeout",
+                                      value > 0 ? value : 0);
 }
 
 /**
@@ -957,9 +936,8 @@ cb_cursor_timeout_button_value_changed (
  *   endif
  */
 static void
-cb_limit_quality_check_button_toggled (
-        GtkToggleButton *button,
-        gpointer user_data)
+cb_limit_quality_check_button_toggled (GtkToggleButton *button,
+                                       gpointer user_data)
 {
     /* Variable Section */
 
@@ -969,10 +947,44 @@ cb_limit_quality_check_button_toggled (
 
     /* Code Section */
 
-    rstto_settings_set_boolean_property (
-            dialog->priv->settings,
-            "limit-quality",
-            limit_quality);
+    rstto_settings_set_boolean_property (dialog->priv->settings, "limit-quality", limit_quality);
+}
+
+/**
+ * cb_enable_smoothing_check_button_toggled:
+ * @button:    The check-button the user clicked.
+ * @user_data: The user-data provided when connecting the
+ *             callback-function, the preferences-dialog.
+ *
+ *
+ * This function is called when a user toggles the 'enable-smoothing'
+ * check-button. This function then sets the right property in the
+ * ristretto settings container.
+ *
+ * When this property is set, the image is smoothed using bilinear
+ * interpolation, thus prioritizing rendering quality over performance.
+ *
+ *
+ *   active = toggle_button_get_active ()
+ *
+ *   if (active) then
+ *
+ *       set_property ("enable-smoothing", TRUE);
+ *
+ *   else
+ *
+ *       set_property ("enable-smoothing", FALSE);
+ *
+ *   endif
+ */
+static void
+cb_enable_smoothing_check_button_toggled (GtkToggleButton *button,
+                                          gpointer user_data)
+{
+    RsttoPreferencesDialog *dialog = user_data;
+    gboolean enable_smoothing = gtk_toggle_button_get_active (button);
+
+    rstto_settings_set_boolean_property (dialog->priv->settings, "enable-smoothing", enable_smoothing);
 }
 
 /**
@@ -1008,9 +1020,8 @@ cb_limit_quality_check_button_toggled (
  *   endif
  */
 static void
-cb_choose_desktop_combo_box_changed (
-        GtkComboBox *combo_box,
-        gpointer user_data)
+cb_choose_desktop_combo_box_changed (GtkComboBox *combo_box,
+                                     gpointer user_data)
 {
     /* Variable Section */
 
@@ -1022,22 +1033,13 @@ cb_choose_desktop_combo_box_changed (
     switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box)))
     {
         case DESKTOP_TYPE_NONE:
-            rstto_settings_set_string_property (
-                    dialog->priv->settings,
-                    "desktop-type",
-                    "none");
+            rstto_settings_set_string_property (dialog->priv->settings, "desktop-type", "none");
             break;
         case DESKTOP_TYPE_XFCE:
-            rstto_settings_set_string_property (
-                    dialog->priv->settings,
-                    "desktop-type",
-                    "xfce");
+            rstto_settings_set_string_property (dialog->priv->settings, "desktop-type", "xfce");
             break;
         case DESKTOP_TYPE_GNOME:
-            rstto_settings_set_string_property (
-                    dialog->priv->settings,
-                    "desktop-type",
-                    "gnome");
+            rstto_settings_set_string_property (dialog->priv->settings, "desktop-type", "gnome");
             break;
     }
 }
