@@ -5,12 +5,12 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -24,45 +24,28 @@
 
 G_BEGIN_DECLS
 
-#define RSTTO_TYPE_PREFERENCES_DIALOG rstto_preferences_dialog_get_type()
+typedef enum
+{
+    DESKTOP_TYPE_NONE = 0,
+    DESKTOP_TYPE_XFCE,
+    DESKTOP_TYPE_GNOME,
+    DESKTOP_TYPE_COUNT
+} RsttoDesktopType;
 
-#define RSTTO_PREFERENCES_DIALOG(obj)( \
-        G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                RSTTO_TYPE_PREFERENCES_DIALOG, \
-                RsttoPreferencesDialog))
 
-#define RSTTO_IS_PREFERENCES_DIALOG(obj)( \
-        G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                RSTTO_TYPE_PREFERENCES_DIALOG))
 
-#define RSTTO_PREFERENCES_DIALOG_CLASS(klass)( \
-        G_TYPE_CHECK_CLASS_CAST ((klass), \
-                RSTTO_TYPE_PREFERENCES_DIALOG, \
-                RsttoPreferencesDialogClass))
+#define RSTTO_TYPE_PREFERENCES_DIALOG rstto_preferences_dialog_get_type ()
+G_DECLARE_FINAL_TYPE (RsttoPreferencesDialog, rstto_preferences_dialog, RSTTO, PREFERENCES_DIALOG, GtkDialog)
 
-#define RSTTO_IS_PREFERENCES_DIALOG_CLASS(klass)( \
-        G_TYPE_CHECK_CLASS_TYPE ((klass), \
-                RSTTO_TYPE_PREFERENCES_DIALOG()))
-
-typedef struct _RsttoPreferencesDialog RsttoPreferencesDialog;
-
-typedef struct _RsttoPreferencesDialogPriv RsttoPreferencesDialogPriv;
+typedef struct _RsttoPreferencesDialogPrivate RsttoPreferencesDialogPrivate;
 
 struct _RsttoPreferencesDialog
 {
     GtkDialog parent;
-    RsttoPreferencesDialogPriv *priv;
+    RsttoPreferencesDialogPrivate *priv;
 };
 
-typedef struct _RsttoPreferencesDialogClass RsttoPreferencesDialogClass;
 
-struct _RsttoPreferencesDialogClass
-{
-    GtkDialogClass parent_class;
-};
-
-GType
-rstto_preferences_dialog_get_type (void);
 
 GtkWidget *
 rstto_preferences_dialog_new (GtkWindow *parent);
