@@ -18,9 +18,9 @@
  */
 
 #include "util.h"
+#include "main_window.h"
 #include "thumbnailer.h"
 #include "tumbler.h"
-#include "main_window.h"
 
 #include <glib/gi18n.h>
 
@@ -33,6 +33,19 @@ enum
     RSTTO_THUMBNAILER_SIGNAL_COUNT
 };
 
+enum
+{
+    TUMBLER_ERROR_UNSUPPORTED,
+    TUMBLER_ERROR_CONNECTION_ERROR,
+    TUMBLER_ERROR_INVALID_FORMAT,
+    TUMBLER_ERROR_IS_THUMBNAIL,
+    TUMBLER_ERROR_SAVE_FAILED,
+    TUMBLER_ERROR_UNSUPPORTED_FLAVOR,
+    TUMBLER_ERROR_NO_CONTENT,
+    TUMBLER_ERROR_SHUTTING_DOWN,
+    TUMBLER_ERROR_OTHER_ERROR_DOMAIN,
+};
+
 static gint rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_COUNT];
 
 static RsttoThumbnailer *thumbnailer_object;
@@ -67,17 +80,17 @@ rstto_thumbnailer_queue_request_timer_destroy (gpointer user_data);
 
 struct _RsttoThumbnailerPrivate
 {
-    GDBusConnection     *connection;
+    GDBusConnection *connection;
     TumblerThumbnailer1 *proxy;
-    RsttoSettings       *settings;
+    RsttoSettings *settings;
 
-    GSList              *remove_queue,
-                        *queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
-                        *in_process_queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
-                        *handles[RSTTO_THUMBNAIL_FLAVOR_COUNT];
-    guint                request_timer_ids[RSTTO_THUMBNAIL_FLAVOR_COUNT];
+    GSList *remove_queue,
+        *queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
+        *in_process_queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
+        *handles[RSTTO_THUMBNAIL_FLAVOR_COUNT];
+    guint request_timer_ids[RSTTO_THUMBNAIL_FLAVOR_COUNT];
 
-    gboolean             show_missing_thumbnailer_error;
+    gboolean show_missing_thumbnailer_error;
 };
 
 
@@ -103,20 +116,19 @@ rstto_thumbnailer_init (RsttoThumbnailer *thumbnailer)
         thumbnailer->priv->request_timer_ids[n] = 0;
     }
 
-    thumbnailer->priv->show_missing_thumbnailer_error =
-            rstto_settings_get_boolean_property (
-                    thumbnailer->priv->settings,
-                    "show-error-missing-thumbnailer");
+    thumbnailer->priv->show_missing_thumbnailer_error = rstto_settings_get_boolean_property (
+        thumbnailer->priv->settings,
+        "show-error-missing-thumbnailer");
 
     if (thumbnailer->priv->connection)
     {
         thumbnailer->priv->proxy = tumbler_thumbnailer1_proxy_new_sync (
-                thumbnailer->priv->connection,
-                G_DBUS_PROXY_FLAGS_NONE,
-                TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1",
-                TUMBLER_SERVICE_PATH_PREFIX "/Thumbnailer1",
-                NULL,
-                &error);
+            thumbnailer->priv->connection,
+            G_DBUS_PROXY_FLAGS_NONE,
+            TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1",
+            TUMBLER_SERVICE_PATH_PREFIX "/Thumbnailer1",
+            NULL,
+            &error);
 
         if (thumbnailer->priv->proxy != NULL)
         {
@@ -144,28 +156,20 @@ rstto_thumbnailer_class_init (RsttoThumbnailerClass *klass)
 
     object_class->finalize = rstto_thumbnailer_finalize;
 
-    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY] = g_signal_new ("ready",
-            G_TYPE_FROM_CLASS (klass),
-            G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-            0,
-            NULL,
-            NULL,
-            g_cclosure_marshal_VOID__OBJECT,
-            G_TYPE_NONE,
-            1,
-            G_TYPE_OBJECT,
-            NULL);
-    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_ERROR] = g_signal_new ("error",
-            G_TYPE_FROM_CLASS (klass),
-            G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-            0,
-            NULL,
-            NULL,
-            g_cclosure_marshal_VOID__OBJECT,
-            G_TYPE_NONE,
-            1,
-            G_TYPE_OBJECT,
-            NULL);
+    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY] =
+        g_signal_new ("ready",
+                      G_TYPE_FROM_CLASS (klass),
+                      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                      0, NULL, NULL,
+                      g_cclosure_marshal_VOID__OBJECT,
+                      G_TYPE_NONE, 1, G_TYPE_OBJECT);
+    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_ERROR] =
+        g_signal_new ("error",
+                      G_TYPE_FROM_CLASS (klass),
+                      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                      0, NULL, NULL,
+                      g_cclosure_marshal_VOID__OBJECT,
+                      G_TYPE_NONE, 1, G_TYPE_OBJECT);
 }
 
 /**
@@ -296,12 +300,14 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
         tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
                                                 GPOINTER_TO_UINT (iter->data), NULL, NULL);
 
-    /* handle current request, whose size doesn't exceed the number of visible items */
-    for (iter = thumbnailer->priv->queues[flavor], i = 0; iter != NULL; iter = iter->next)
+    /* handle current request, up to the number of visible items */
+    for (iter = thumbnailer->priv->queues[flavor], i = 0;
+         iter != NULL && i < n_items;
+         iter = iter->next)
     {
         /* directories are loaded without this costly filtering, so it is done
          * here only when required */
-        if (! rstto_file_is_valid (iter->data))
+        if (!rstto_file_is_valid (iter->data))
         {
             thumbnailer->priv->remove_queue =
                 g_slist_prepend (thumbnailer->priv->remove_queue, iter->data);
@@ -341,11 +347,11 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
     thumbnailer->priv->in_process_queues[flavor] = g_slist_reverse (temp);
 
     if (thumbnailer->priv->proxy == NULL
-        || ! tumbler_thumbnailer1_call_queue_sync (thumbnailer->priv->proxy,
-                                                   (const gchar * const*) uris,
-                                                   (const gchar * const*) mimetypes,
-                                                   rstto_util_get_thumbnail_flavor_name (flavor),
-                                                   "default", 0, &handle, NULL, &error))
+        || !tumbler_thumbnailer1_call_queue_sync (thumbnailer->priv->proxy,
+                                                  (const gchar *const *) uris,
+                                                  (const gchar *const *) mimetypes,
+                                                  rstto_util_get_thumbnail_flavor_name (flavor),
+                                                  "default", 0, &handle, NULL, &error))
     {
         if (NULL != error)
         {
@@ -355,36 +361,29 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
                 && thumbnailer->priv->show_missing_thumbnailer_error)
             {
                 error_dialog = gtk_message_dialog_new_with_markup (
-                        GTK_WINDOW (rstto_main_window_get_app_window ()),
-                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                        GTK_MESSAGE_WARNING,
-                        GTK_BUTTONS_OK,
-                        _("The thumbnailer-service can not be reached,\n"
-                        "for this reason, the thumbnails can not be\n"
-                        "created.\n\n"
-                        "Install <b>Tumbler</b> or another <i>thumbnailing daemon</i>\n"
-                        "to resolve this issue."));
-                vbox = gtk_dialog_get_content_area (
-                        GTK_DIALOG (error_dialog));
+                    GTK_WINDOW (rstto_main_window_get_app_window ()),
+                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                    GTK_MESSAGE_WARNING,
+                    GTK_BUTTONS_OK,
+                    _("The thumbnailer-service can not be reached,\n"
+                      "for this reason, the thumbnails can not be\n"
+                      "created.\n\n"
+                      "Install <b>Tumbler</b> or another <i>thumbnailing daemon</i>\n"
+                      "to resolve this issue."));
+                vbox = gtk_dialog_get_content_area (GTK_DIALOG (error_dialog));
 
                 do_not_show_checkbox = gtk_check_button_new_with_mnemonic (
-                        _("Do _not show this message again"));
-                gtk_box_pack_end (
-                        GTK_BOX (vbox),
-                        do_not_show_checkbox,
-                        TRUE,
-                        FALSE,
-                        0);
+                    _("Do _not show this message again"));
+                gtk_box_pack_end (GTK_BOX (vbox), do_not_show_checkbox, TRUE, FALSE, 0);
                 gtk_widget_show (do_not_show_checkbox);
                 gtk_dialog_run (GTK_DIALOG (error_dialog));
 
                 thumbnailer->priv->show_missing_thumbnailer_error = FALSE;
                 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (do_not_show_checkbox)))
                 {
-                    rstto_settings_set_boolean_property (
-                        thumbnailer->priv->settings,
-                        "show-error-missing-thumbnailer",
-                         FALSE);
+                    rstto_settings_set_boolean_property (thumbnailer->priv->settings,
+                                                         "show-error-missing-thumbnailer",
+                                                         FALSE);
                 }
                 gtk_widget_destroy (error_dialog);
             }
@@ -489,9 +488,19 @@ cb_rstto_thumbnailer_thumbnail_error (TumblerThumbnailer1 *proxy,
         if (g_strcmp0 (uris[n], rstto_file_get_uri (iter->data)) == 0)
         {
             /* it was probably cancelled when we unqueued files above, and since it is in the
-             * queue here, we wanted it to be processed: back to square one, state unchanged */
+             * queue here, we wanted it to be processed: back to square one, state unchanged
+             * NOTE: tumbler no longer emits an error signal in this case since 4.17.0: see
+             * tumbler@49ffba98d7cf9626a1470bc49a53596300fe3550 */
             if (error_code == G_IO_ERROR_CANCELLED)
                 rstto_thumbnailer_queue_file (thumbnailer, flavor, iter->data);
+            else if (error_code == TUMBLER_ERROR_IS_THUMBNAIL)
+            {
+                rstto_file_set_is_thumbnail (iter->data, TRUE);
+                rstto_file_set_thumbnail_state (iter->data, flavor, RSTTO_THUMBNAIL_STATE_PROCESSED);
+                g_signal_emit (thumbnailer,
+                               rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY],
+                               0, iter->data, NULL);
+            }
             else
             {
                 rstto_file_set_thumbnail_state (iter->data, flavor, RSTTO_THUMBNAIL_STATE_ERROR);
