@@ -27,10 +27,9 @@ G_DEFINE_INTERFACE (RsttoWallpaperManager, rstto_wallpaper_manager, G_TYPE_OBJEC
 
 
 gint
-rstto_wallpaper_manager_configure_dialog_run (
-        RsttoWallpaperManager *self,
-        RsttoFile *file,
-        GtkWindow *parent)
+rstto_wallpaper_manager_configure_dialog_run (RsttoWallpaperManager *self,
+                                              RsttoFile *file,
+                                              GtkWindow *parent)
 {
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->configure_dialog_run (self, file, parent);
 }
@@ -42,9 +41,8 @@ rstto_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 }
 
 gboolean
-rstto_wallpaper_manager_set (
-        RsttoWallpaperManager *self,
-        RsttoFile *file)
+rstto_wallpaper_manager_set (RsttoWallpaperManager *self,
+                             RsttoFile *file)
 {
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->set (self, file);
 }
