@@ -22,12 +22,12 @@
 #include "xfce_wallpaper_manager.h"
 
 #ifdef HAVE_LIBX11
-#include <gdk/gdkx.h>
 #include <X11/Xatom.h>
+#include <gdk/gdkx.h>
 #endif
 
-#include <xfconf/xfconf.h>
 #include <libxfce4ui/libxfce4ui.h>
+#include <xfconf/xfconf.h>
 
 
 
@@ -70,7 +70,8 @@ cb_workspace_mode_changed (GtkCheckButton *check_button,
 
 
 
-typedef struct {
+typedef struct
+{
     guint16 r;
     guint16 g;
     guint16 b;
@@ -80,8 +81,8 @@ typedef struct {
 struct _RsttoXfceWallpaperManagerPrivate
 {
     XfconfChannel *channel;
-    gint    screen;
-    gint    monitor;
+    gint screen;
+    gint monitor;
     enum MonitorStyle style;
     RsttoColor *color1;
     RsttoColor *color2;
@@ -107,10 +108,9 @@ G_DEFINE_TYPE_WITH_CODE (RsttoXfceWallpaperManager, rstto_xfce_wallpaper_manager
 
 
 static gint
-rstto_xfce_wallpaper_manager_configure_dialog_run (
-        RsttoWallpaperManager *self,
-        RsttoFile *file,
-        GtkWindow *parent)
+rstto_xfce_wallpaper_manager_configure_dialog_run (RsttoWallpaperManager *self,
+                                                   RsttoFile *file,
+                                                   GtkWindow *parent)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
     gint response = 0;
@@ -121,11 +121,7 @@ rstto_xfce_wallpaper_manager_configure_dialog_run (
         g_object_unref (manager->priv->pixbuf);
     }
 
-    manager->priv->pixbuf = gdk_pixbuf_new_from_file_at_size (
-            rstto_file_get_path (file),
-            500,
-            500,
-            NULL);
+    manager->priv->pixbuf = gdk_pixbuf_new_from_file_at_size (rstto_file_get_path (file), 500, 500, NULL);
 
     configure_monitor_chooser_pixbuf (manager);
 
@@ -135,11 +131,11 @@ rstto_xfce_wallpaper_manager_configure_dialog_run (
     if ((response == GTK_RESPONSE_OK) || (response == GTK_RESPONSE_APPLY))
     {
         manager->priv->style = gtk_combo_box_get_active (
-                GTK_COMBO_BOX (manager->priv->style_combo));
+            GTK_COMBO_BOX (manager->priv->style_combo));
         manager->priv->monitor = rstto_monitor_chooser_get_selected (
-                RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
+            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
         manager->priv->workspace_mode = gtk_toggle_button_get_active (
-                GTK_TOGGLE_BUTTON (manager->priv->check_button));
+            GTK_TOGGLE_BUTTON (manager->priv->check_button));
     }
 
     return response;
@@ -170,7 +166,8 @@ rstto_xfce_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 }
 
 static gboolean
-rstto_xfce_wallpaper_manager_set (RsttoWallpaperManager *self, RsttoFile *file)
+rstto_xfce_wallpaper_manager_set (RsttoWallpaperManager *self,
+                                  RsttoFile *file)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
 
@@ -255,20 +252,17 @@ rstto_xfce_wallpaper_manager_init (RsttoXfceWallpaperManager *manager)
     GtkWidget *image_prop_grid = gtk_grid_new ();
 
     manager->priv = rstto_xfce_wallpaper_manager_get_instance_private (manager);
-    if (! rstto_settings_get_xfconf_disabled ())
+    if (!rstto_settings_get_xfconf_disabled ())
         manager->priv->channel = xfconf_channel_new ("xfce4-desktop");
     manager->priv->color1 = g_new0 (RsttoColor, 1);
     manager->priv->color1->a = 0xffff;
     manager->priv->color2 = g_new0 (RsttoColor, 1);
     manager->priv->color2->a = 0xffff;
     manager->priv->style = 3; /* stretched is now default value */
-    manager->priv->check_button = gtk_check_button_new_with_label (
-            _("Apply to all workspaces"));
+    manager->priv->check_button = gtk_check_button_new_with_label ( _("Apply to all workspaces"));
     if (manager->priv->channel != NULL)
-        manager->priv->workspace_mode = xfconf_channel_get_bool (
-                manager->priv->channel,
-                SINGLE_WORKSPACE_MODE,
-                TRUE);
+        manager->priv->workspace_mode =
+            xfconf_channel_get_bool (manager->priv->channel, SINGLE_WORKSPACE_MODE, TRUE);
 
     manager->priv->dialog = gtk_dialog_new ();
     gtk_window_set_title (GTK_WINDOW (manager->priv->dialog), _("Set as wallpaper"));
@@ -293,66 +287,26 @@ rstto_xfce_wallpaper_manager_init (RsttoXfceWallpaperManager *manager)
 
     for (i = 0; i < n_monitors; ++i)
     {
-        gdk_monitor_get_geometry (
-                gdk_display_get_monitor (display, i),
-                &monitor_geometry);
-        rstto_monitor_chooser_add (
-                RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-                monitor_geometry.width,
-                monitor_geometry.height);
+        gdk_monitor_get_geometry (gdk_display_get_monitor (display, i), &monitor_geometry);
+        rstto_monitor_chooser_add (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                   monitor_geometry.width, monitor_geometry.height);
     }
 
-    gtk_box_pack_start (
-            GTK_BOX (vbox),
-            manager->priv->monitor_chooser,
-            FALSE,
-            FALSE,
-            0);
-    gtk_box_pack_start (
-            GTK_BOX (vbox),
-            image_prop_grid,
-            FALSE,
-            FALSE,
-            0);
+    gtk_box_pack_start (GTK_BOX (vbox), manager->priv->monitor_chooser, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), image_prop_grid, FALSE, FALSE, 0);
 
-    gtk_grid_attach (
-            GTK_GRID (image_prop_grid),
-            style_label,
-            0,
-            0,
-            1,
-            1);
-    gtk_grid_attach (
-            GTK_GRID (image_prop_grid),
-            manager->priv->style_combo,
-            1,
-            0,
-            1,
-            1);
+    gtk_grid_attach (GTK_GRID (image_prop_grid), style_label, 0, 0, 1, 1);
+    gtk_grid_attach (GTK_GRID (image_prop_grid), manager->priv->style_combo, 1, 0, 1, 1);
 
     gtk_widget_set_hexpand (manager->priv->style_combo, TRUE);
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Auto"));
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Centered"));
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Tiled"));
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Stretched"));
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Scaled"));
-    gtk_combo_box_text_append_text (
-            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
-            _("Zoomed"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Auto"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Centered"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Tiled"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Stretched"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Scaled"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (manager->priv->style_combo), _("Zoomed"));
 
-    gtk_combo_box_set_active (
-            GTK_COMBO_BOX (manager->priv->style_combo),
-            3);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (manager->priv->style_combo), 3);
 
     // there's only one screen in GTK3
     manager->priv->screen = 0;
@@ -364,20 +318,11 @@ rstto_xfce_wallpaper_manager_init (RsttoXfceWallpaperManager *manager)
     g_signal_connect (manager->priv->style_combo, "changed",
                       G_CALLBACK (cb_style_combo_changed), manager);
 
-    gtk_toggle_button_set_active (
-            GTK_TOGGLE_BUTTON (manager->priv->check_button),
-            manager->priv->workspace_mode);
-    gtk_grid_attach (
-            GTK_GRID (image_prop_grid),
-            manager->priv->check_button,
-            0,
-            1,
-            2,
-            1);
-    g_signal_connect (manager->priv->check_button,
-            "toggled",
-            G_CALLBACK (cb_workspace_mode_changed),
-            manager);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (manager->priv->check_button),
+                                  manager->priv->workspace_mode);
+    gtk_grid_attach (GTK_GRID (image_prop_grid), manager->priv->check_button, 0, 1, 2, 1);
+    g_signal_connect (manager->priv->check_button, "toggled",
+                      G_CALLBACK (cb_workspace_mode_changed), manager);
 
     gtk_widget_show_all (vbox);
 }
@@ -430,9 +375,7 @@ rstto_xfce_wallpaper_manager_new (void)
 {
     if (xfce_wallpaper_manager_object == NULL)
     {
-        xfce_wallpaper_manager_object = g_object_new (
-                RSTTO_TYPE_XFCE_WALLPAPER_MANAGER,
-                NULL);
+        xfce_wallpaper_manager_object = g_object_new (RSTTO_TYPE_XFCE_WALLPAPER_MANAGER, NULL);
     }
     else
     {
@@ -454,37 +397,35 @@ rstto_get_active_workspace_number (GdkScreen *screen)
     if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
     {
         GdkWindow *root;
-        gulong     bytes_after_ret = 0;
-        gulong     nitems_ret = 0;
-        guint     *prop_ret = NULL;
-        Atom       _NET_CURRENT_DESKTOP;
-        Atom       _WIN_WORKSPACE;
-        Atom       type_ret = None;
-        gint       format_ret;
+        gulong bytes_after_ret = 0;
+        gulong nitems_ret = 0;
+        guint *prop_ret = NULL;
+        Atom _NET_CURRENT_DESKTOP;
+        Atom _WIN_WORKSPACE;
+        Atom type_ret = None;
+        gint format_ret;
 
         gdk_x11_display_error_trap_push (gdk_screen_get_display (screen));
 
         root = gdk_screen_get_root_window (screen);
 
         /* determine the X atom values */
-        _NET_CURRENT_DESKTOP = XInternAtom (GDK_WINDOW_XDISPLAY (root),
-                "_NET_CURRENT_DESKTOP",
-                False);
-        _WIN_WORKSPACE = XInternAtom (GDK_WINDOW_XDISPLAY (root),
-                "_WIN_WORKSPACE",
-                False);
+        _NET_CURRENT_DESKTOP = XInternAtom (GDK_WINDOW_XDISPLAY (root), "_NET_CURRENT_DESKTOP", False);
+        _WIN_WORKSPACE = XInternAtom (GDK_WINDOW_XDISPLAY (root), "_WIN_WORKSPACE", False);
 
         if (XGetWindowProperty (GDK_WINDOW_XDISPLAY (root),
-                gdk_x11_get_default_root_xwindow (),
-                _NET_CURRENT_DESKTOP, 0, 32, False, XA_CARDINAL,
-                &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
-                (gpointer) &prop_ret) != Success)
+                                gdk_x11_get_default_root_xwindow (),
+                                _NET_CURRENT_DESKTOP, 0, 32, False, XA_CARDINAL,
+                                &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
+                                (gpointer) &prop_ret)
+            != Success)
         {
             if (XGetWindowProperty (GDK_WINDOW_XDISPLAY (root),
-                    gdk_x11_get_default_root_xwindow (),
-                    _WIN_WORKSPACE, 0, 32, False, XA_CARDINAL,
-                    &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
-                    (gpointer) &prop_ret) != Success)
+                                    gdk_x11_get_default_root_xwindow (),
+                                    _WIN_WORKSPACE, 0, 32, False, XA_CARDINAL,
+                                    &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
+                                    (gpointer) &prop_ret)
+                != Success)
             {
                 if (G_UNLIKELY (prop_ret != NULL))
                 {
@@ -509,79 +450,60 @@ rstto_get_active_workspace_number (GdkScreen *screen)
 }
 
 static void
-cb_style_combo_changed (
-        GtkComboBox *style_combo,
-        RsttoXfceWallpaperManager *manager)
+cb_style_combo_changed (GtkComboBox *style_combo,
+                        RsttoXfceWallpaperManager *manager)
 {
     manager->priv->style = gtk_combo_box_get_active (style_combo);
 
     manager->priv->monitor = rstto_monitor_chooser_get_selected (
-            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
+        RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser));
 
     configure_monitor_chooser_pixbuf (manager);
 }
 
 static void
-cb_workspace_mode_changed (
-        GtkCheckButton *button,
-        RsttoXfceWallpaperManager *manager)
+cb_workspace_mode_changed (GtkCheckButton *button,
+                           RsttoXfceWallpaperManager *manager)
 {
     gboolean active;
 
-    active = gtk_toggle_button_get_active (
-            GTK_TOGGLE_BUTTON (button));
+    active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
     if (manager->priv->channel != NULL)
-        xfconf_channel_set_bool (manager->priv->channel,
-                SINGLE_WORKSPACE_MODE,
-                active);
+        xfconf_channel_set_bool (manager->priv->channel, SINGLE_WORKSPACE_MODE, active);
 }
 
 static void
-cb_monitor_chooser_changed (
-        RsttoMonitorChooser *monitor_chooser,
-        RsttoXfceWallpaperManager *manager)
+cb_monitor_chooser_changed (RsttoMonitorChooser *monitor_chooser,
+                            RsttoXfceWallpaperManager *manager)
 {
-    rstto_monitor_chooser_set_image_surface (
-            monitor_chooser,
-            manager->priv->monitor,
-            NULL,
-            NULL);
-
+    rstto_monitor_chooser_set_image_surface (monitor_chooser, manager->priv->monitor, NULL, NULL);
     manager->priv->monitor = rstto_monitor_chooser_get_selected (monitor_chooser);
-
     configure_monitor_chooser_pixbuf (manager);
 }
 
 static void
-configure_monitor_chooser_pixbuf (
-    RsttoXfceWallpaperManager *manager)
+configure_monitor_chooser_pixbuf (RsttoXfceWallpaperManager *manager)
 {
     cairo_surface_t *image_surface = NULL;
     cairo_t *ctx;
     GdkPixbuf *tmp_pixbuf;
     gdouble x_scale, y_scale;
     gint monitor_width, monitor_height, surface_width, surface_height,
-         dest_x, dest_y, dest_width, dest_height;
+        dest_x, dest_y, dest_width, dest_height;
 
     if (manager->priv->pixbuf)
     {
         tmp_pixbuf = gdk_pixbuf_copy (manager->priv->pixbuf);
         if (NULL != tmp_pixbuf)
         {
-            rstto_monitor_chooser_get_dimensions (
-                    RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-                    manager->priv->monitor,
-                    &monitor_width,
-                    &monitor_height);
+            rstto_monitor_chooser_get_dimensions (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                                  manager->priv->monitor, &monitor_width, &monitor_height);
 
             surface_width = monitor_width * 0.2;
             surface_height = monitor_height * 0.2;
 
-            image_surface = cairo_image_surface_create (
-                    CAIRO_FORMAT_ARGB32,
-                    surface_width,
-                    surface_height);
+            image_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, surface_width, surface_height);
             ctx = cairo_create (image_surface);
 
             cairo_set_source_rgb (ctx, 0, 0, 0);
@@ -636,19 +558,11 @@ configure_monitor_chooser_pixbuf (
                 default:
                     dest_x = 0;
                     dest_y = 0;
-                    gdk_pixbuf_saturate_and_pixelate (
-                        tmp_pixbuf,
-                        tmp_pixbuf,
-                        0.0,
-                        TRUE);
+                    gdk_pixbuf_saturate_and_pixelate (tmp_pixbuf, tmp_pixbuf, 0.0, TRUE);
                     break;
             }
             cairo_scale (ctx, x_scale, y_scale);
-            gdk_cairo_set_source_pixbuf (
-                    ctx,
-                    tmp_pixbuf,
-                    dest_x / x_scale,
-                    dest_y / y_scale);
+            gdk_cairo_set_source_pixbuf (ctx, tmp_pixbuf, dest_x / x_scale, dest_y / y_scale);
             cairo_paint (ctx);
             cairo_destroy (ctx);
 
@@ -656,9 +570,6 @@ configure_monitor_chooser_pixbuf (
         }
     }
 
-    rstto_monitor_chooser_set_image_surface (
-            RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
-            manager->priv->monitor,
-            image_surface,
-            NULL);
+    rstto_monitor_chooser_set_image_surface (RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
+                                             manager->priv->monitor, image_surface, NULL);
 }
